package com.biganto.visual.roompark.data.local

import android.content.Context
import com.afollestad.rxkprefs.rxkPrefs
import com.biganto.visual.androidplayer.data.repository.local.ILocalStore
import io.reactivex.Completable
import io.reactivex.Observable
import javax.inject.Inject
import javax.inject.Singleton

/**
 * Created by Vladislav Bogdashkin on 14.06.2018.
 */

@Singleton
class UserHolder @Inject constructor(val context : Context) : ILocalStore
{
    private val prefs = rxkPrefs(context)

    companion object {
        const val RECENT_UUID_KEY = "com.biganto.visual.androidplayer.LAST_USER_UUD"
        const val EMPTY_PREF_VALUE_KEY = "NO_ACTIVE_SESSION"

        const val SCROLL_LIST_TO_TOUR_KEY="SCROLL_LIST_TO_TOUR_ID"


    }

    override fun setDownloadListDestinationTourId(tourId:String) =
            prefs.string(SCROLL_LIST_TO_TOUR_KEY,tourId)
                .observe()

    override fun getDownloadListDestinationTourId() =
            prefs.string(SCROLL_LIST_TO_TOUR_KEY,"")
                .observe()

    override fun recentUser(): Observable<in UserState> =
            prefs.string(RECENT_UUID_KEY, EMPTY_PREF_VALUE_KEY)
                .observe()
                    .map {
                        if (it == EMPTY_PREF_VALUE_KEY) return@map UserState.NotAuthenticated()
                        else return@map UserState.Authenticated(it)
                    }

    override fun setRecentUser(uuid: String?) =
            Completable.fromObservable(prefs.string(RECENT_UUID_KEY, uuid ?: EMPTY_PREF_VALUE_KEY).observe())
}

sealed class UserState{
    class NotAuthenticated
    data class Authenticated(val uuid: String)
}

data class UserPrefModel(
        val uuid:String
        ,val name:String
        ,val email:String
        ,val timeZone:String)
